<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * @package    mod
 * @subpackage checkoutcome
 * @copyright  2012 Olivier Le Borgne <olivier.leborgne@univ-nantes.fr>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

/** example constant */
//define('NEWMODULE_ULTIMATE_ANSWER', 42);

////////////////////////////////////////////////////////////////////////////////
// Moodle core API                                                            //
////////////////////////////////////////////////////////////////////////////////

/**
 * Returns the information on whether the module supports a feature
 *
 * @see plugin_supports() in lib/moodlelib.php
 * @param string $feature FEATURE_xx constant for requested feature
 * @return mixed true if the feature is supported, null if unknown
 */
function checkoutcome_supports($feature) {
    switch($feature) {
        case FEATURE_MOD_INTRO:         	return true;
        case FEATURE_GROUPS:	         	return true;
        case FEATURE_GROUPINGS:         	return true;
        case FEATURE_GROUPMEMBERSONLY:     	return true;
        case FEATURE_BACKUP_MOODLE2:          return true;        
        default:                        	return null;
    }
}

/**
 * Saves a new instance of the checkoutcome into the database
 *
 * Given an object containing all the necessary data,
 * (defined by the form in mod_form.php) this function
 * will create a new instance and return the id number
 * of the new instance.
 *
 * @param object $checkoutcome An object from the form in mod_form.php
 * @param mod_checkoutcome_mod_form $mform
 * @return int The id of the newly inserted checkoutcome record
 */
function checkoutcome_add_instance(stdClass $checkoutcome, mod_checkoutcome_mod_form $mform = null) {
    global $DB;

    $checkoutcome->timecreated = time();

    # You may have to add extra stuff in here #

    return $DB->insert_record('checkoutcome', $checkoutcome);
}

/**
 * Updates an instance of the checkoutcome in the database
 *
 * Given an object containing all the necessary data,
 * (defined by the form in mod_form.php) this function
 * will update an existing instance with new data.
 *
 * @param object $checkoutcome An object from the form in mod_form.php
 * @param mod_checkoutcome_mod_form $mform
 * @return boolean Success/Fail
 */
function checkoutcome_update_instance(stdClass $checkoutcome, mod_checkoutcome_mod_form $mform = null) {
    global $DB;

    $checkoutcome->timemodified = time();
    $checkoutcome->id = $checkoutcome->instance;

    # You may have to add extra stuff in here #

    return $DB->update_record('checkoutcome', $checkoutcome);
}

/**
 * Removes an instance of the checkoutcome from the database
 *
 * Given an ID of an instance of this module,
 * this function will permanently delete the instance
 * and any data that depends on it.
 *
 * @param int $id Id of the module instance
 * @return boolean Success/Failure
 */
function checkoutcome_delete_instance($id) {
    global $DB;

    if (! $checkoutcome = $DB->get_record('checkoutcome', array('id' => $id))) {
        return false;
    }

    # Delete any dependent records here #

    $DB->delete_records('checkoutcome', array('id' => $checkoutcome->id));

    return true;
}

/**
 * Returns a small object with summary information about what a
 * user has done with a given particular instance of this module
 * Used for user activity reports.
 * $return->time = the time they did it
 * $return->info = a short text description
 *
 * @return stdClass|null
 */
function checkoutcome_user_outline($course, $user, $mod, $checkoutcome) {

    $return = new stdClass();
    $return->time = 0;
    $return->info = '';
    return $return;
}

/**
 * Prints a detailed representation of what a user has done with
 * a given particular instance of this module, for user activity reports.
 *
 * @param stdClass $course the current course record
 * @param stdClass $user the record of the user we are generating report for
 * @param cm_info $mod course module info
 * @param stdClass $checkoutcome the module instance record
 * @return void, is supposed to echp directly
 */
function checkoutcome_user_complete($course, $user, $mod, $checkoutcome) {
}

/**
 * Given a course and a time, this module should find recent activity
 * that has occurred in checkoutcome activities and print it out.
 * Return true if there was output, or false is there was none.
 *
 * @return boolean
 */
function checkoutcome_print_recent_activity($course, $viewfullnames, $timestart) {
    return false;  //  True if anything was printed, otherwise false
}

/**
 * Prepares the recent activity data
 *
 * This callback function is supposed to populate the passed array with
 * custom activity records. These records are then rendered into HTML via
 * {@link checkoutcome_print_recent_mod_activity()}.
 *
 * @param array $activities sequentially indexed array of objects with the 'cmid' property
 * @param int $index the index in the $activities to use for the next record
 * @param int $timestart append activity since this time
 * @param int $courseid the id of the course we produce the report for
 * @param int $cmid course module id
 * @param int $userid check for a particular user's activity only, defaults to 0 (all users)
 * @param int $groupid check for a particular group's activity only, defaults to 0 (all groups)
 * @return void adds items into $activities and increases $index
 */
function checkoutcome_get_recent_mod_activity(&$activities, &$index, $timestart, $courseid, $cmid, $userid=0, $groupid=0) {
}

/**
 * Prints single activity item prepared by {@see checkoutcome_get_recent_mod_activity()}

 * @return void
 */
function checkoutcome_print_recent_mod_activity($activity, $courseid, $detail, $modnames, $viewfullnames) {
}

/**
 * Function to be run periodically according to the moodle cron
 * This function searches for things that need to be done, such
 * as sending out mail, toggling flags etc ...
 *
 * @return boolean
 * @todo Finish documenting this function
 **/
function checkoutcome_cron () {
    return true;
}

/**
 * Returns an array of users who are participanting in this checkoutcome
 *
 * Must return an array of users who are participants for a given instance
 * of checkoutcome. Must include every user involved in the instance,
 * independient of his role (student, teacher, admin...). The returned
 * objects must contain at least id property.
 * See other modules as example.
 *
 * @param int $checkoutcomeid ID of an instance of this module
 * @return boolean|array false if no participants, array of objects otherwise
 */
function checkoutcome_get_participants($checkoutcomeid) {
    return false;
}

/**
 * Returns all other caps used in the module
 *
 * @example return array('moodle/site:accessallgroups');
 * @return array
 */
function checkoutcome_get_extra_capabilities() {
    return array();
}

////////////////////////////////////////////////////////////////////////////////
// Gradebook API                                                              //
////////////////////////////////////////////////////////////////////////////////

/**
 * Is a given scale used by the instance of checkoutcome?
 *
 * This function returns if a scale is being used by one checkoutcome
 * if it has support for grading and scales. Commented code should be
 * modified if necessary. See forum, glossary or journal modules
 * as reference.
 *
 * @param int $checkoutcomeid ID of an instance of this module
 * @return bool true if the scale is used by the given checkoutcome instance
 */
function checkoutcome_scale_used($checkoutcomeid, $scaleid) {
    global $DB;

    /** @example */
    if ($scaleid and $DB->record_exists('checkoutcome', array('id' => $checkoutcomeid, 'grade' => -$scaleid))) {
        return true;
    } else {
        return false;
    }
}

/**
 * Checks if scale is being used by any instance of checkoutcome.
 *
 * This is used to find out if scale used anywhere.
 *
 * @param $scaleid int
 * @return boolean true if the scale is used by any checkoutcome instance
 */
function checkoutcome_scale_used_anywhere($scaleid) {
    return false;
}

/**
 * Creates or updates grade item for the give checkoutcome instance
 *
 * Needed by grade_update_mod_grades() in lib/gradelib.php
 *
 * @param stdClass $checkoutcome instance object with extra cmidnumber and modname property
 * @return void
 */
function checkoutcome_grade_item_update(stdClass $checkoutcome) {
    global $CFG;
    require_once($CFG->libdir.'/gradelib.php');

    /** @example */
    $item = array();
    $item['itemname'] = clean_param($checkoutcome->name, PARAM_NOTAGS);
    $item['gradetype'] = GRADE_TYPE_VALUE;
    $item['grademax']  = $checkoutcome->grade;
    $item['grademin']  = 0;

    grade_update('mod/checkoutcome', $checkoutcome->course, 'mod', 'checkoutcome', $checkoutcome->id, 0, null, $item);
}

/**
 * Update checkoutcome grades in the gradebook
 *
 * Needed by grade_update_mod_grades() in lib/gradelib.php
 *
 * @param stdClass $checkoutcome instance object with extra cmidnumber and modname property
 * @param int $userid update grade of specific user only, 0 means all participants
 * @return void
 */
function checkoutcome_update_grades(stdClass $checkoutcome, $userid = 0) {
    global $CFG, $DB;
    require_once($CFG->libdir.'/gradelib.php');

    /** @example */
    $grades = array(); // populate array of grade objects indexed by userid

    grade_update('mod/checkoutcome', $checkoutcome->course, 'mod', 'checkoutcome', $checkoutcome->id, 0, $grades);
}

////////////////////////////////////////////////////////////////////////////////
// File API                                                                   //
////////////////////////////////////////////////////////////////////////////////

/**
 * Returns the lists of all browsable file areas within the given module context
 *
 * The file area 'intro' for the activity introduction field is added automatically
 * by {@link file_browser::get_file_info_context_module()}
 *
 * @param stdClass $course
 * @param stdClass $cm
 * @param stdClass $context
 * @return array of [(string)filearea] => (string)description
 */
function checkoutcome_get_file_areas($course, $cm, $context) {
    return array();
}

/**
 * Serves the files from the checkoutcome file areas
 *
 * @param stdClass $course
 * @param stdClass $cm
 * @param stdClass $context
 * @param string $filearea
 * @param array $args
 * @param bool $forcedownload
 * @return void this should never return to the caller
 */
function checkoutcome_pluginfile($course, $cm, $context, $filearea, array $args, $forcedownload) {
    global $DB, $CFG;

    if ($context->contextlevel != CONTEXT_MODULE) {
        return false;
    }

    require_login($course, false, $cm);

    // verifier qu'un checkoutcome est installé dans ce cours
    if (! $checkoutcome = $DB->get_record("checkoutcome", array("id" => "$cm->instance"))) {
        return false;
    }

    return checkoutcome_send_file($course, $cm, $context, $filearea, $args);
}

function checkoutcome_send_file($course, $cm, $context, $filearea, $args) {
	// affiche le contenu d'un fichier
	global $CFG, $DB, $USER;
	require_once($CFG->libdir.'/filelib.php');

	require_login($course, false, $cm);

	// DEBUG
	// echo "<br>DEBUG :: lib.php :: 110 :: <br>CONTEXT : $context->id :: FILEAREA : $filearea<br>ARGS:\n";
	// print_r($args);
	//
	$docid = (int)array_shift($args);

	// verifier les fileareas acceptables
	$fileareas = array('checkoutcome', 'document');
	if (!in_array($filearea, $fileareas)) {
		return false;
	}

	if ($filearea=='document'){
		if (!$document = $DB->get_record('checkoutcome_document', array('id'=>$docid))) {
			return false;
		}
	}

	$relativepath = implode('/', $args);
	$fullpath = '/'.$context->id.'/mod_checkoutcome/'.$filearea.'/'.$docid.'/'.$relativepath;

	$fs = get_file_storage();

	if (!$file = $fs->get_file_by_hash(sha1($fullpath)) or $file->is_directory()) {
		return false;
	}

	send_stored_file($file, 0, 0, true); // download MUST be forced - security!
}

////////////////////////////////////////////////////////////////////////////////
// Navigation API                                                             //
////////////////////////////////////////////////////////////////////////////////

/**
 * Extends the global navigation tree by adding checkoutcome nodes if there is a relevant content
 *
 * This can be called by an AJAX request so do not rely on $PAGE as it might not be set up properly.
 *
 * @param navigation_node $navref An object representing the navigation tree node of the checkoutcome module instance
 * @param stdClass $course
 * @param stdClass $module
 * @param cm_info $cm
 */
function checkoutcome_extend_navigation(navigation_node $navref, stdclass $course, stdclass $module, cm_info $cm) {
}

/**
 * Extends the settings navigation with the checkoutcome settings
 *
 * This function is called when the context for the page is a checkoutcome module. This is not called by AJAX
 * so it is safe to rely on the $PAGE.
 *
 * @param settings_navigation $settingsnav {@link settings_navigation}
 * @param navigation_node $checkoutcomenode {@link navigation_node}
 */
function checkoutcome_extend_settings_navigation(settings_navigation $settingsnav, navigation_node $checkoutcomenode=null) {
}
